==> kdeplasma-addons-4.2.3.tar.bz2: kdeplasma-addons-4.2.3/applets/pastebin/backends/server.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Thomas Georgiou <TAGeorgiou@gmail.com>          *
 *                         Artur Duque de Souza <morpheuz@gmail.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef PASTEBIN_SERVER_H
#define PASTEBIN_SERVER_H

#include <QObject>

class PastebinServer : public QObject
{
    Q_OBJECT

public:
    PastebinServer();
    virtual ~PastebinServer();
    virtual void post(QString content) = 0;

Q_SIGNALS:
    void postFinished(const QString &data);

protected:
    const QString m_server;

};

#endif

==> kdeplasma-addons-4.3.4.tar.bz2: kdeplasma-addons-4.3.4/applets/pastebin/backends/server.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Thomas Georgiou <TAGeorgiou@gmail.com>          *
 *                         Artur Duque de Souza <morpheuz@gmail.com>       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef PASTEBIN_SERVER_H
#define PASTEBIN_SERVER_H

#include <QObject>

class PastebinServer : public QObject
{
    Q_OBJECT

public:
    virtual ~PastebinServer();
    virtual void post(const QString& content) = 0;

signals:
    void postFinished(const QString &data);
    void postError();

protected:
    // abstract class
    PastebinServer();
    QString m_server;

};

#endif
